Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
__init__.py | 1 | 0 | 0 | 100%
cc_modules/__init__.py | 0 | 0 | 0 | 100%
cc_modules/cc_alembic.py | 42 | 24 | 0 | 43%
cc_modules/cc_all_models.py | 48 | 1 | 0 | 98%
cc_modules/cc_anon.py | 162 | 135 | 0 | 17%
cc_modules/cc_argparse.py | 3 | 0 | 0 | 100%
cc_modules/cc_audit.py | 40 | 3 | 0 | 92%
cc_modules/cc_baseconstants.py | 34 | 4 | 0 | 88%
cc_modules/cc_blob.py | 83 | 39 | 0 | 53%
cc_modules/cc_cache.py | 5 | 0 | 0 | 100%
cc_modules/cc_client_api_core.py | 302 | 27 | 0 | 91%
cc_modules/cc_client_api_helpers.py | 6 | 0 | 0 | 100%
cc_modules/cc_config.py | 457 | 173 | 0 | 62%
cc_modules/cc_constants.py | 662 | 18 | 0 | 97%
cc_modules/cc_convert.py | 45 | 5 | 0 | 89%
cc_modules/cc_ctvinfo.py | 8 | 0 | 0 | 100%
cc_modules/cc_dataclasses.py | 32 | 12 | 0 | 62%
cc_modules/cc_db.py | 399 | 192 | 0 | 52%
cc_modules/cc_debug.py | 36 | 29 | 0 | 19%
cc_modules/cc_device.py | 81 | 20 | 0 | 75%
cc_modules/cc_dirtytables.py | 11 | 0 | 0 | 100%
cc_modules/cc_dummy_database.py | 222 | 165 | 0 | 26%
cc_modules/cc_dump.py | 221 | 171 | 0 | 23%
cc_modules/cc_email.py | 99 | 59 | 0 | 40%
cc_modules/cc_exception.py | 10 | 2 | 0 | 80%
cc_modules/cc_export.py | 476 | 328 | 0 | 31%
cc_modules/cc_exportmodels.py | 464 | 312 | 0 | 33%
cc_modules/cc_exportrecipient.py | 165 | 69 | 0 | 58%
cc_modules/cc_exportrecipientinfo.py | 389 | 257 | 0 | 34%
cc_modules/cc_fhir.py | 175 | 100 | 0 | 43%
cc_modules/cc_filename.py | 96 | 64 | 0 | 33%
cc_modules/cc_formatter.py | 15 | 6 | 0 | 60%
cc_modules/cc_forms.py | 2284 | 1090 | 0 | 52%
cc_modules/cc_group.py | 77 | 19 | 0 | 75%
cc_modules/cc_hl7.py | 290 | 251 | 0 | 13%
cc_modules/cc_html.py | 124 | 80 | 0 | 35%
cc_modules/cc_idnumdef.py | 62 | 14 | 0 | 77%
cc_modules/cc_ipuse.py | 29 | 2 | 0 | 93%
cc_modules/cc_language.py | 6 | 0 | 0 | 100%
cc_modules/cc_mako_helperfunc.py | 12 | 8 | 0 | 33%
cc_modules/cc_membership.py | 29 | 3 | 0 | 90%
cc_modules/cc_nhs.py | 10 | 3 | 0 | 70%
cc_modules/cc_nlp.py | 25 | 22 | 0 | 12%
cc_modules/cc_password.py | 7 | 5 | 0 | 29%
cc_modules/cc_patient.py | 394 | 253 | 0 | 36%
cc_modules/cc_patientidnum.py | 81 | 35 | 0 | 57%
cc_modules/cc_pdf.py | 10 | 5 | 0 | 50%
cc_modules/cc_plot.py | 23 | 2 | 0 | 91%
cc_modules/cc_policy.py | 448 | 321 | 0 | 28%
cc_modules/cc_proquint.py | 75 | 2 | 0 | 97%
cc_modules/cc_pyramid.py | 803 | 199 | 0 | 75%
cc_modules/cc_pythonversion.py | 9 | 5 | 0 | 44%
cc_modules/cc_redcap.py | 264 | 192 | 0 | 27%
cc_modules/cc_report.py | 279 | 192 | 0 | 31%
cc_modules/cc_reportschema.py | 39 | 10 | 0 | 74%
cc_modules/cc_request.py | 667 | 304 | 0 | 54%
cc_modules/cc_resource_registry.py | 7 | 3 | 0 | 57%
cc_modules/cc_response.py | 12 | 5 | 0 | 58%
cc_modules/cc_serversettings.py | 50 | 5 | 0 | 90%
cc_modules/cc_session.py | 160 | 70 | 0 | 56%
cc_modules/cc_simpleobjects.py | 72 | 30 | 0 | 58%
cc_modules/cc_sms.py | 55 | 16 | 0 | 71%
cc_modules/cc_snomed.py | 454 | 180 | 0 | 60%
cc_modules/cc_specialnote.py | 84 | 43 | 0 | 49%
cc_modules/cc_spreadsheet.py | 266 | 189 | 0 | 29%
cc_modules/cc_sqla_coltypes.py | 491 | 169 | 0 | 66%
cc_modules/cc_sqlalchemy.py | 81 | 31 | 0 | 62%
cc_modules/cc_string.py | 96 | 37 | 0 | 61%
cc_modules/cc_summaryelement.py | 47 | 24 | 0 | 49%
cc_modules/cc_tabletsession.py | 103 | 21 | 0 | 80%
cc_modules/cc_task.py | 910 | 564 | 0 | 38%
cc_modules/cc_taskcollection.py | 376 | 208 | 0 | 45%
cc_modules/cc_taskfactory.py | 43 | 22 | 0 | 49%
cc_modules/cc_taskfilter.py | 210 | 68 | 0 | 68%
cc_modules/cc_taskindex.py | 294 | 130 | 0 | 56%
cc_modules/cc_taskreports.py | 154 | 106 | 0 | 31%
cc_modules/cc_taskschedule.py | 154 | 35 | 0 | 77%
cc_modules/cc_taskschedulereports.py | 132 | 84 | 0 | 36%
cc_modules/cc_testfactories.py | 245 | 21 | 0 | 91%
cc_modules/cc_testproviders.py | 52 | 3 | 0 | 94%
cc_modules/cc_text.py | 134 | 85 | 0 | 37%
cc_modules/cc_tracker.py | 258 | 205 | 0 | 21%
cc_modules/cc_trackerhelpers.py | 52 | 31 | 0 | 40%
cc_modules/cc_unittest.py | 117 | 56 | 0 | 52%
cc_modules/cc_user.py | 526 | 289 | 0 | 45%
cc_modules/cc_validators.py | 148 | 81 | 0 | 45%
cc_modules/cc_version.py | 29 | 13 | 0 | 55%
cc_modules/cc_version_string.py | 3 | 0 | 0 | 100%
cc_modules/cc_view_classes.py | 280 | 149 | 0 | 47%
cc_modules/cc_xml.py | 155 | 95 | 0 | 39%
cc_modules/celery.py | 132 | 79 | 0 | 40%
cc_modules/client_api.py | 913 | 83 | 0 | 91%
cc_modules/merge_db.py | 283 | 232 | 0 | 18%
cc_modules/tests/__init__.py | 0 | 0 | 0 | 100%
cc_modules/tests/client_api_tests.py | 1032 | 4 | 0 | 99%
cc_modules/webview.py | 2277 | 1703 | 0 | 25%
conftest.py | 138 | 32 | 0 | 77%
tasks/__init__.py | 119 | 0 | 0 | 100%
tasks/ace3.py | 314 | 147 | 0 | 53%
tasks/aims.py | 58 | 24 | 0 | 59%
tasks/apeq_cpft_perinatal.py | 130 | 67 | 0 | 48%
tasks/apeqpt.py | 61 | 32 | 0 | 48%
tasks/aq.py | 122 | 65 | 0 | 47%
tasks/asdas.py | 99 | 55 | 0 | 44%
tasks/audit.py | 119 | 67 | 0 | 44%
tasks/badls.py | 55 | 23 | 0 | 58%
tasks/basdai.py | 72 | 40 | 0 | 44%
tasks/bdi.py | 103 | 55 | 0 | 47%
tasks/bmi.py | 109 | 67 | 0 | 39%
tasks/bprs.py | 54 | 21 | 0 | 61%
tasks/bprse.py | 47 | 17 | 0 | 64%
tasks/cage.py | 58 | 25 | 0 | 57%
tasks/cape42.py | 136 | 83 | 0 | 39%
tasks/caps.py | 84 | 48 | 0 | 43%
tasks/cardinal_expdetthreshold.py | 234 | 156 | 0 | 33%
tasks/cardinal_expectationdetection.py | 458 | 315 | 0 | 31%
tasks/cbir.py | 87 | 44 | 0 | 49%
tasks/ceca.py | 616 | 332 | 0 | 46%
tasks/cesd.py | 72 | 30 | 0 | 58%
tasks/cesdr.py | 108 | 52 | 0 | 52%
tasks/cet.py | 114 | 58 | 0 | 49%
tasks/cgi_task.py | 76 | 32 | 0 | 58%
tasks/cgisch.py | 54 | 27 | 0 | 50%
tasks/chit.py | 52 | 20 | 0 | 62%
tasks/cia.py | 64 | 32 | 0 | 50%
tasks/cisr.py | 1984 | 1156 | 0 | 42%
tasks/ciwa.py | 77 | 36 | 0 | 53%
tasks/contactlog.py | 36 | 8 | 0 | 78%
tasks/cope.py | 81 | 34 | 0 | 58%
tasks/core10.py | 96 | 36 | 0 | 62%
tasks/cpft_covid_medical.py | 34 | 14 | 0 | 59%
tasks/cpft_lps.py | 367 | 181 | 0 | 51%
tasks/cpft_research_preferences.py | 45 | 19 | 0 | 58%
tasks/dad.py | 98 | 59 | 0 | 40%
tasks/das28.py | 128 | 69 | 0 | 46%
tasks/dast.py | 65 | 31 | 0 | 52%
tasks/deakin_s1_healthreview.py | 126 | 9 | 0 | 93%
tasks/demoquestionnaire.py | 137 | 71 | 0 | 48%
tasks/demqol.py | 140 | 69 | 0 | 51%
tasks/diagnosis.py | 398 | 220 | 0 | 45%
tasks/distressthermometer.py | 53 | 27 | 0 | 49%
tasks/edeq.py | 109 | 54 | 0 | 50%
tasks/elixhauserci.py | 37 | 11 | 0 | 70%
tasks/empsa.py | 95 | 26 | 0 | 73%
tasks/epds.py | 55 | 23 | 0 | 58%
tasks/eq5d5l.py | 62 | 27 | 0 | 56%
tasks/esspri.py | 48 | 18 | 0 | 62%
tasks/factg.py | 123 | 55 | 0 | 55%
tasks/fast.py | 61 | 29 | 0 | 52%
tasks/fft.py | 28 | 9 | 0 | 68%
tasks/frs.py | 116 | 60 | 0 | 48%
tasks/gad7.py | 65 | 31 | 0 | 52%
tasks/gaf.py | 41 | 15 | 0 | 63%
tasks/gbo.py | 178 | 63 | 0 | 65%
tasks/gds.py | 61 | 26 | 0 | 57%
tasks/gmcpq.py | 105 | 58 | 0 | 45%
tasks/hads.py | 89 | 39 | 0 | 56%
tasks/hama.py | 61 | 29 | 0 | 52%
tasks/hamd.py | 120 | 70 | 0 | 42%
tasks/hamd7.py | 66 | 31 | 0 | 53%
tasks/honos.py | 176 | 86 | 0 | 51%
tasks/icd10depressive.py | 213 | 137 | 0 | 36%
tasks/icd10manic.py | 175 | 111 | 0 | 37%
tasks/icd10mixed.py | 50 | 19 | 0 | 62%
tasks/icd10schizophrenia.py | 132 | 62 | 0 | 53%
tasks/icd10schizotypal.py | 63 | 26 | 0 | 59%
tasks/icd10specpd.py | 235 | 133 | 0 | 43%
tasks/ided3d.py | 135 | 42 | 0 | 69%
tasks/iesr.py | 79 | 30 | 0 | 62%
tasks/ifs.py | 135 | 84 | 0 | 38%
tasks/irac.py | 29 | 9 | 0 | 69%
tasks/isaaq10.py | 31 | 8 | 0 | 74%
tasks/isaaqcommon.py | 35 | 21 | 0 | 40%
tasks/isaaqed.py | 28 | 8 | 0 | 71%
tasks/khandaker_insight_medical.py | 60 | 24 | 0 | 60%
tasks/khandaker_mojo_medical.py | 129 | 40 | 0 | 69%
tasks/khandaker_mojo_medicationtherapy.py | 93 | 35 | 0 | 62%
tasks/khandaker_mojo_sociodemographics.py | 78 | 32 | 0 | 59%
tasks/kirby_mcq.py | 172 | 112 | 0 | 35%
tasks/lynall_iam_life.py | 94 | 43 | 0 | 54%
tasks/lynall_iam_medical.py | 127 | 61 | 0 | 52%
tasks/maas.py | 113 | 57 | 0 | 50%
tasks/mast.py | 74 | 38 | 0 | 49%
tasks/mds_updrs.py | 117 | 16 | 0 | 86%
tasks/mfi20.py | 83 | 33 | 0 | 60%
tasks/moca.py | 124 | 57 | 0 | 54%
tasks/nart.py | 92 | 50 | 0 | 46%
tasks/npiq.py | 87 | 50 | 0 | 43%
tasks/ors.py | 54 | 22 | 0 | 59%
tasks/panss.py | 79 | 27 | 0 | 66%
tasks/paradise24.py | 55 | 29 | 0 | 47%
tasks/pbq.py | 104 | 36 | 0 | 65%
tasks/pcl.py | 108 | 47 | 0 | 56%
tasks/pcl5.py | 91 | 46 | 0 | 49%
tasks/pdss.py | 60 | 23 | 0 | 62%
tasks/perinatalpoem.py | 235 | 103 | 0 | 56%
tasks/photo.py | 84 | 31 | 0 | 63%
tasks/phq15.py | 87 | 50 | 0 | 43%
tasks/phq8.py | 87 | 45 | 0 | 48%
tasks/phq9.py | 111 | 65 | 0 | 41%
tasks/progressnote.py | 33 | 10 | 0 | 70%
tasks/pswq.py | 63 | 27 | 0 | 57%
tasks/psychiatricclerking.py | 183 | 105 | 0 | 43%
tasks/qolbasic.py | 54 | 21 | 0 | 61%
tasks/qolsg.py | 67 | 27 | 0 | 60%
tasks/rand36.py | 170 | 110 | 0 | 35%
tasks/rapid3.py | 112 | 54 | 0 | 52%
tasks/service_satisfaction.py | 58 | 18 | 0 | 69%
tasks/sfmpq2.py | 61 | 22 | 0 | 64%
tasks/shaps.py | 55 | 25 | 0 | 55%
tasks/slums.py | 106 | 48 | 0 | 55%
tasks/smast.py | 71 | 36 | 0 | 49%
tasks/srs.py | 42 | 14 | 0 | 67%
tasks/suppsp.py | 81 | 32 | 0 | 60%
tasks/tests/__init__.py | 0 | 0 | 0 | 100%
tasks/tests/factories.py | 810 | 51 | 0 | 94%
tasks/wemwbs.py | 98 | 40 | 0 | 59%
tasks/wsas.py | 66 | 26 | 0 | 61%
tasks/ybocs.py | 124 | 50 | 0 | 60%
tasks/zbi.py | 48 | 18 | 0 | 62%
Total | 37337 | 17762 | 0 | 52%

No items found using the specified filter.